"""Module containing all of the SARIF reporters for Flake8."""
import hashlib
import json
import os
from pathlib import Path


class sarifdata:
    """Collect the results of the checks for SARIF format."""

    def __init__(self, rule_id, rule_level, rule_full_desc, full_file_path,
                 root_dir_path, result_message, start_line, start_column,
                 code_snippet):
        """Init a new sarifdata object."""
        self.rule_id = rule_id
        self.rule_level = rule_level
        self.rule_full_desc = rule_full_desc
        self.full_file_path = full_file_path
        self.root_dir_path = root_dir_path
        self.result_message = result_message
        self.start_line = start_line
        self.start_column = start_column
        self.code_snippet = code_snippet

    def get_relative_path(self):
        """Return path of the file relative to the root folder."""
        if self.root_dir_path is None:
            path = os.path.dirname(os.path.abspath(self.full_file_path))
        else:
            path = os.path.abspath(self.root_dir_path)
        path = Path(self.full_file_path).relative_to(path)
        return str(path).replace('\\', '/')

    def get_base_dir_file_uri(self):
        """Return file uri of the root folder."""
        if self.root_dir_path is None:
            path = os.path.dirname(os.path.abspath(self.full_file_path))
        else:
            path = os.path.abspath(self.root_dir_path)
        return Path(path).as_uri() + '/'
